### Name: Formula
### Title: Extended Formulas
### Aliases: Formula is.Formula formula.Formula terms.Formula
###   update.Formula model.matrix.Formula model.frame.Formula
###   length.Formula as.Formula as.Formula.default as.Formula.formula
###   has.intercept has.intercept.formula has.intercept.Formula
### Keywords: classes

### ** Examples

data("airquality", package = "datasets")
f <- Ozone ~ Solar.R + Wind | Temp

# create a Formula object from the formula
f2 <- Formula(f)
class(f2)

# examples of updates of the two-parts formula
update(f2,. ~ . - Wind + Day | . + Month)
update(f2,. ~ . | . + Month)
update(f2,. ~ . - Wind + Day | .)

# get the first, second and both parts, with or without the response
formula(f2, part = "first", response = TRUE)
formula(f2, part = "second", response = FALSE)
formula(f2, part = "both")

# model.frame for the first part and for both parts
head(model.frame(f2, part = "first", data = airquality))
head(model.frame(f2, part = "both", data = airquality))

# model.matrix for the first and the second part
head(model.matrix(f2, data = airquality, part = "first"))
head(model.matrix(f2, data = airquality, part = "second"))

# note that the sample is not the same due to missing values
mf <- model.frame(f2, part = "both", data = airquality)
head(model.matrix(f2, data = mf, part = "first"))
head(model.matrix(f2, data = mf, part = "second"))



